@@ -1,7 +1,7 @@
 package MojoMojo::Controller::Page;
 
 use strict;
-use base 'Catalyst::Controller';
+use parent 'Catalyst::Controller';
 use IO::Scalar;
 use URI;
 use Text::Context;
@@ -17,7 +17,7 @@ MojoMojo::Controller::Page - Page controller
 
 =head1 DESCRIPTION
 
-This controller is the main juice of MojoMojo. it handles all the
+This controller is the main juice of MojoMojo. It handles all the
 actions related to wiki pages. Actions are redispatched to this
 controller based on a Regex controller in the main MojoMojo class.
 
@@ -30,7 +30,7 @@ can be called with urls like "/page1/page2.action".
 
 This is probably the most common action in MojoMojo. A lot of the
 other actions redispatch to this one. It will prepare the stash
-for page view, and set the template to view.tt, unless another is
+for page view, and set the template to C<view.tt>, unless another is
 already set.
 
 It also takes an optional 'rev' parameter, in which case it will
@@ -38,15 +38,17 @@ load the provided revision instead.
 
 =cut
 
-sub view : Global {
+sub view :Global {
     my ( $self, $c, $path ) = @_;
 
     my $stash = $c->stash;
     $stash->{template} ||= 'page/view.tt';
 
     $c->forward('inline_tags');
-    $c->stash->{render} = 'highlight'
-      if $c->req->referer && $c->req->referer =~ /.edit$/;
+# FIXME NOTE: Highlight has been turned off until someone makes it work perfectly in all cases.
+# In particular it sucks with TOC and valid HTML
+# $c->stash->{render} = 'highlight'
+#  if $c->req->referer && $c->req->referer =~ /.edit$/;
 
     my ( $path_pages, $proto_pages, $id ) =
       @$stash{qw/ path_pages proto_pages id /};
@@ -108,13 +110,13 @@ sub view : Global {
 
 =head2 search (.search)
 
-This action is called as .search on the current page when the user
-performs a search.  The user can choose whether or not to search
-the entire site or a subtree starting from the current page.
+This action is called as C<.search> on the current page when the user
+performs a search.  The user can choose to search the entire site or a
+subtree starting from the current page.
 
 =cut
 
-sub search : Global {
+sub search :Global {
     my ( $self, $c ) = @_;
 
     my $stash = $c->stash;
@@ -133,20 +135,19 @@ sub search : Global {
 
     my $results = [];
 
-# for subtree searches, add the path info to the query, replacing slashes with X
+    # for subtree searches, add the path info to the query, replacing slashes with X
     my $real_query = $q;    # this is for context matching later
     if ( $search_type eq "subtree" ) {
         my $fixed_path = $page->path;
-        $fixed_path =~ s/\//X/g;
+        $fixed_path =~ s{/}{X}g;
         $q = "path:$fixed_path* AND " . $q;
     }
 
     my $hits = $c->model('Search')->search($q);
     my %results_hash;
     while ( my $hit = $hits->fetch_hit_hashref ) {
-        $hit->{path} =~ s/X/\//g;
-        my ($path_pages) =
-          $c->model('DBIC::Page')->path_pages( $hit->{path} );
+        $hit->{path} =~ s{X}{/}g;
+        my ($path_pages) = $c->model('DBIC::Page')->path_pages( $hit->{path} );
         my $page = $path_pages->[ @$path_pages - 1 ];
 
         # skip search result depending on permissions
@@ -200,9 +201,9 @@ sub search : Global {
     my $result_count = scalar @$results;
     if ($result_count) {
 
-# Paginate the results
-# This is done even with even 1 page of results so the template doesn't need to do
-# two separate things
+        # Paginate the results.
+        # This is done even with 1 page of results so the template doesn't need
+        # to do two separate things.
         my $pager = Data::Page->new;
         $pager->total_entries($result_count);
         $pager->entries_per_page($results_per_page);
@@ -225,17 +226,28 @@ sub search : Global {
 
 =head2 print
 
-this action is the same as the view action, with another template
+This action is the same as the L</view> action, but with a printer-friendly
+template.
 
 =cut
 
-sub print : Global {
+sub print :Global {
     my ( $self, $c, $page ) = @_;
     $c->stash->{template} = 'page/print.tt';
     $c->forward('view');
 }
 
-sub inline : Global {
+
+=head2 inline
+
+Same as L</view> action, but with a template that only outputs the barebones
+body of the page. There are no headers, footers, or navigation bars. Useful
+for transclusion.
+
+=cut
+
+
+sub inline :Global {
     my ( $self, $c, $page ) = @_;
     $c->stash->{template} = 'page/inline.tt';
     $c->forward('view');
@@ -248,7 +260,7 @@ Tag list for the bottom of page views.
 
 =cut
 
-sub inline_tags : Global {
+sub inline_tags :Global {
     my ( $self, $c, $highlight ) = @_;
     $c->stash->{template} ||= 'page/tags.tt';
     $c->stash->{highlight} = $highlight;
@@ -265,70 +277,96 @@ sub inline_tags : Global {
     }
 }
 
-=head2 list (.list)
 
-all nodes in this namespace
+=head2 pages_viewable($c, $user, @pages)
+
+Filters an array of pages, returning only those that the given user has
+permission to view.
 
 =cut
 
-sub list : Global {
+sub pages_viewable {
+    my ($c, $user, @pages) = @_;
+    return grep {
+        $c->check_permissions( $_->path, $user )->{view};
+    } @pages;
+}
+
+=head2 list (.list)
+
+All nodes in this namespace. Computes tags, all pages, backlinks, wanted and
+orphan pages.
+
+=cut
+
+sub list :Global {
     my ( $self, $c, $tag ) = @_;
     my $page = $c->stash->{page};
     $c->stash->{tags} = $c->model("DBIC::Tag")->most_used();
     $c->detach('/tag/list') if $tag;
     $c->stash->{template} = 'page/list.tt';
-    
-    if ( $c->pref('check_permission_on_view') ) {
-      my $user;
-      my @pages;
-      my @all_pages = $page->descendants;
-      if ( $c->user_exists() ) { $user = $c->user->obj; }
-      foreach my $page_to_check (@all_pages) {
-        # skip pages without view permissions
-        my $perms = $c->check_permissions( $page_to_check->path, $user );
-        next unless $perms->{'view'};
-        push @pages,$page_to_check;
-      }
-      $c->stash->{pages}    = [ @pages ];
-    } else {
-      $c->stash->{pages}    = [ $page->descendants ];
-    }
 
-    # FIXME - real data here please
-    $c->stash->{orphans} = [];
-    $c->stash->{backlinks} =
-      [ $c->model("DBIC::Link")->search( to_page => $page->id ) ];
+    # Cache the list page for short period of time - override default of 300.
+    $c->cache_page($c->config->{'Plugin::PageCache'}{page_cache_short_life});
+
+    my @all_pages_viewable = $page->descendants;
+    my @backlinks_viewable = $c->model("DBIC::Link")->search( to_page => $page->id );
+    if ( $c->pref('check_permission_on_view') ) {
+        my $user;
+        if ( $c->user_exists() ) { $user = $c->user->obj; }
+        @all_pages_viewable = pages_viewable($c, $user, @all_pages_viewable);
+        @backlinks_viewable = grep {
+            # does the user have permission to view the page from which ours is linked?
+            $c->check_permissions( $_->from_page->path, $user )->{view};
+        } @backlinks_viewable;
+    }
+    $c->stash->{pages} = \@all_pages_viewable;
+    $c->stash->{backlinks} = \@backlinks_viewable;
+
+    $c->stash->{orphans} = [];  # FIXME - real data here please
+
+    # no need to check any permissions here because the user already views this page, and wanted pages are redlinks in it
     $c->stash->{wanted} = [
         $c->model("DBIC::WantedPage")->search(
-            { from_page => [ $page->id, map { $_->id } $page->descendants ] }
+            { from_page => [ $page->id, map { $_->id } @all_pages_viewable ] }
         )
     ];
 }
 
 =head2 recent (.recent)
 
-recently changed nodes in this namespace.
+Recently changed pages in this namespace.
 
 =cut
 
-sub recent : Global {
+sub recent :Global {
     my ( $self, $c, $tag ) = @_;
     $c->detach( '/tag/recent', [$tag] ) if $tag;
     $c->stash->{tags} = $c->model("DBIC::Tag")->most_used;
     my $page = $c->stash->{page};
     $c->stash->{template} = 'page/recent.tt';
-    $c->stash->{pages}    = [ $page->descendants_by_date ];
+
+    my @pages_viewable = $page->descendants_by_date;
+    if ( $c->pref('check_permission_on_view') ) {
+        my $user;
+        if ( $c->user_exists() ) { $user = $c->user->obj; }
+        @pages_viewable = pages_viewable($c, $user, @pages_viewable);
+    }
+    $c->stash->{pages} = \@pages_viewable;
+
+    # Cache the list page for short period of time - override default of 300.
+    $c->cache_page($c->config->{'Plugin::PageCache'}{page_cache_short_life});
 
     # FIXME - needs to be populated even without tags
 }
 
 =head2 feeds (.feeds)
 
-overview of available feeds for this node.
+Overview of available feeds for this node.
 
 =cut
 
-sub feeds : Global {
+sub feeds :Global {
     my ( $self, $c ) = @_;
     $c->stash->{template} = 'feeds.tt';
 }
@@ -339,21 +377,21 @@ RSS feed with headlines of recent nodes in this namespace.
 
 =cut
 
-sub rss : Global {
+sub rss :Global {
     my ( $self, $c ) = @_;
     $c->forward('recent');
     $c->stash->{template} = 'page/rss.tt';
     $c->res->content_type('application/rss+xml');
 }
 
+
 =head2 atom (.atom)
 
 Full content ATOM feed of recent nodes in this namespace.
 
-
 =cut
 
-sub atom : Global {
+sub atom :Global {
     my ( $self, $c ) = @_;
     $c->forward('recent');
     $c->res->content_type('application/atom+xml');
@@ -366,31 +404,32 @@ Full content RSS feed of recent nodes in this namespace.
 
 =cut
 
-sub rss_full : Global {
+sub rss_full :Global {
     my ( $self, $c ) = @_;
     $c->forward('recent');
     $c->res->content_type('application/rss+xml');
     $c->stash->{template} = 'page/rss_full.tt';
 }
 
-=head2  export (.export)
+
+=head2 export (.export)
 
 Page showing available export options.
 
 =cut
 
-sub export : Global {
+sub export :Global {
     my ( $self, $c ) = @_;
     $c->stash->{template} = 'export.tt';
 }
 
 =head2 suggest (.suggest)
 
-Page not found page, suggesting alternatives, and allowing you to create the page.
+"Page not found" page, suggesting alternatives, and allowing creation of the page.
 
 =cut
 
-sub suggest : Global {
+sub suggest :Global {
     my ( $self, $c ) = @_;
     $c->stash->{template} = 'page/suggest.tt';
     $c->res->status(404);
@@ -398,11 +437,11 @@ sub suggest : Global {
 
 =head2 search_inline (.search/inline)
 
-embedded search results in another page (for use with suggest).
+Search results embeddable in another page (for use with L</suggest>).
 
 =cut
 
-sub search_inline : Path('/search/inline') {
+sub search_inline :Path('/search/inline') {
     my ( $self, $c ) = @_;
     $c->forward('search');
     $c->stash->{template} = 'page/search_inline.tt';
@@ -410,11 +449,12 @@ sub search_inline : Path('/search/inline') {
 
 =head2 info (.info)
 
-Display meta information about the current page.
+Meta information about the current page: revision list, content size, number of
+children and descendants, links to/from, attachments.
 
 =cut
 
-sub info : Global {
+sub info :Global {
     my ( $self, $c ) = @_;
     $c->stash->{body_length} = length( $c->stash->{page}->content->body );
     $c->stash->{template}    = 'page/info.tt';
@@ -427,7 +467,7 @@ Marcus Ramberg <mramberg@cpan.org>
 =head1 LICENSE
 
 This library is free software. You can redistribute it and/or modify
-it under the same terms as perl itself.
+it under the same terms as Perl itself.
 
 =cut
 
