@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use Data::Dumper;
 
-use base qw/MojoMojo::Schema::Base::Result/;
+use parent qw/MojoMojo::Schema::Base::Result/;
 
-__PACKAGE__->load_components( "PK::Auto", "Core" );
+__PACKAGE__->load_components( "Core" );
 __PACKAGE__->table("path_permissions");
 __PACKAGE__->add_columns(
     "path",               { data_type => "VARCHAR", is_nullable => 0, size => 255 },
