@@ -1,5 +1,5 @@
 package MojoMojo::View::JSON;
-use base qw( Catalyst::View::JSON );
+use parent qw( Catalyst::View::JSON );
 
 __PACKAGE__->config->{expose_stash}='json';
 
