@@ -31,58 +31,27 @@ $(document).ready(function() {
         $('<li/>').append($split_edit_button)
     );
 
-    if($.cookies.get('split_edit')=='1'){
+    // Set edit mode to normal view (not splitted), if cookie is 0.
+    var split_edit_cookie = $.cookies.get('split_edit');
+    if ( split_edit_cookie == 0 ){
         $split_edit_button.click();
     }
 });
 
 // toggles between horizontal and vertical splitting of the preview and edit areas
 toggle_split_mode = function() {
-    var max_container_width       = $(window).width();
-    // At one point preview was allowed to grown in the vertical dimension
-	//var preview_area_height       = '100%';
-    var edit_area_height          = '40em';
-	// This a bit taller than the edit area 
-	// because we don't have toolbars and such in preview.
-	var preview_area_height       = '50em';
-    var preview_area_max_width    = max_container_width/2;
-    var $content_preview          = $("#content_preview");
-   
+  
+    // if already vertically splitted 
     if ($("div#edit_form").css('float')=='left'){
-        // switch to horizontal split: preview area above edit area
-        $("div#edit_form").css('float',toggle_split_mode.deff);
-        $content_preview.css('float',toggle_split_mode.dcpf);
-        $content_preview.css('width',toggle_split_mode.dcpw);
-        $content_preview.css('height', '100%');
-        $("div#edit_form").css('width',toggle_split_mode.defw);
-        $("div#container").css("max-width",toggle_split_mode.dcmw);
-        $("div#header").css("background-repeat",toggle_split_mode.dhbr);
-        $content_preview.css("height",toggle_split_mode.dph);
-        $("textarea#body").css("height",toggle_split_mode.tbh);
-        //$("div.preview").css("max-width",toggle_split_mode.dpmw);
-        $content_preview.css("max-width",'100%');
+        $("div#content_preview").css('width','100%');
+        $("div#edit_form").css('width','100%');
+        $("div#edit_form").css('float','right');
         $.cookies.set('split_edit',0);
     } else {
         // switch to vertical split: preview area to the left of edit area
-        toggle_split_mode.deff=$('div#edit_form').css('float');
-        toggle_split_mode.dcpf=$content_preview.css('float');
-        toggle_split_mode.dcpw=$content_preview.css('width');
-        toggle_split_mode.defw=$('div#edit_form').css('width');
-        toggle_split_mode.dcmw=$('div#container').css('max-width');
-        toggle_split_mode.dhbr=$('div#header').css('background-repeat');
-        toggle_split_mode.dph=$content_preview.css('height');
-        toggle_split_mode.tbh=$('textarea#body').css('height');
-        //toggle_split_mode.dpmw=$('div.preview').css('max-width');
         $("div#edit_form").css('float','left');
+        $("div#content_preview").css('width','49%');
         $("div#edit_form").css('width','49%');
-        $content_preview.css('float','left');
-        $content_preview.css('width','49%');
-        $content_preview.css('height', preview_area_height );
-        $("div#container").css("max-width", max_container_width);
-        $("div#header").css('background-repeat', 'no-repeat');
-        $("textarea#body").css('height', edit_area_height);
-        $content_preview.css('max-width', preview_area_max_width);
-        $content_preview.css('margin-right','1em');
         $.cookies.set('split_edit',1);
     }
 };
